require_relative "helper"

MINIMUM = "*" * 10
MAXIMUM = "*" * 20
EXACT   = "*" * 8

class Signup < Scrivener
  attr_accessor :fname
  attr_accessor :lname
  attr_accessor :passport

  def validate
    assert_minimum_length :fname, MINIMUM.length
    assert_maximum_length :lname, MAXIMUM.length
    assert_exact_length   :passport, EXACT.length
  end
end

setup do
  Signup.new(fname: MINIMUM, lname: MAXIMUM, passport: EXACT)
end

test "valid" do |signup|
  assert signup.valid?
  assert signup.errors.empty?
end

test "invalid minimum length" do |signup|
  signup.fname = ""

  assert !(signup.valid?)
  assert_equal [:too_short], signup.errors[:fname]
end

test "invalid maximum length" do |signup|
  signup.lname = MAXIMUM + "*"

  assert !(signup.valid?)
  assert_equal [:too_long], signup.errors[:lname]
end

test "invalid exact length" do |signup|
  signup.passport = ""

  assert !(signup.valid?)
  assert_equal [:wrong_length], signup.errors[:passport]
end
